package com.atol.drivers.examples.fptrexample;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.AsyncTask;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.atol.drivers.fptr.Fptr;
import com.atol.drivers.fptr.IFptr;
import com.atol.drivers.fptr.settings.SettingsActivity;

import java.math.BigDecimal;
import java.util.Random;

public class FptrExampleActivity extends Activity {
	private static final String FPTR_PREFERENCES = "FPTR_PREFERENCES";
	private static final int REQUEST_SHOW_SETTINGS = 1;
	private Button runButton;
	private Button settingsButton;
	private Button testButton;
	private TextView log;
	private SharedPreferences preferences;
	private Button cancelButton;
	private LinearLayout buttonsLayout;
	private static final boolean PRINT_FISCAL_CHECK = true;
	private static final boolean PRINT_NONFISCAL_CHECK = true;
	private static final boolean USE_FZ54 = true;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		preferences = getSharedPreferences(FPTR_PREFERENCES, Context.MODE_PRIVATE);

		setContentView(R.layout.activity_main);
		buttonsLayout = (LinearLayout) findViewById(R.id.buttons_layout);
		settingsButton = (Button) findViewById(R.id.settings_button);
		testButton = (Button) findViewById(R.id.test_button);
		runButton = (Button) findViewById(R.id.run_button);
		cancelButton = (Button) findViewById(R.id.cancel_button);
		log = (TextView) findViewById(R.id.log);

		settingsButton.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				Intent intent = new Intent(FptrExampleActivity.this, SettingsActivity.class);
				String settings = getSettings();
				if (settings == null) {
					settings = getDefaultSettings();
				}
				intent.putExtra(SettingsActivity.DEVICE_SETTINGS, settings);
				startActivityForResult(intent, REQUEST_SHOW_SETTINGS);
			}
		});

		testButton.setOnClickListener(new View.OnClickListener() {
			AsyncTask<Void, String, Void> task;

			@Override
			public void onClick(View v) {
				log.setText("");
				task = new AsyncTask<Void, String, Void>() {
					private IFptr fptr;

					private void checkError() throws DriverException {
						int rc = fptr.get_ResultCode();
						if (rc < 0) {
							String rd = fptr.get_ResultDescription(), bpd = null;
							if (rc == -6) {
								bpd = fptr.get_BadParamDescription();
							}
							if (bpd != null) {
								throw new DriverException(String.format("[%d] %s (%s)", rc, rd, bpd));
							} else {
								throw new DriverException(String.format("[%d] %s", rc, rd));
							}
						}
					}

					@Override
					protected void onPreExecute() {
						buttonsLayout.setVisibility(View.GONE);
					}

					@Override
					protected void onPostExecute(Void result) {
						buttonsLayout.setVisibility(View.VISIBLE);
					}

					@Override
					protected Void doInBackground(Void... params) {
						fptr = new Fptr();
						try {
							fptr.create(getApplication());
							publishProgress("Загрузка настроек");
							if (fptr.put_DeviceSettings(getSettings()) < 0) {
								checkError();
							}
							publishProgress("Установка соединения...");
							if (fptr.put_DeviceEnabled(true) < 0) {
								checkError();
							}
							publishProgress("OK");
							publishProgress("Проверка связи...");
							if (fptr.GetStatus() < 0) {
								checkError();
							}
							publishProgress("OK");
						} catch (Exception e) {
							publishProgress(e.toString());
						} finally {
							fptr.destroy();
						}
						return null;
					}

					@Override
					protected void onProgressUpdate(String... values) {
						if (values == null || values.length == 0) {
							return;
						}
						logAdd(values[0]);
					}

				};
				task.execute();
			}
		});

		runButton.setOnClickListener(new View.OnClickListener() {
			AsyncTask<Void, String, Void> task;

			@Override
			public void onClick(View v) {
				log.setText("");
				task = new AsyncTask<Void, String, Void>() {
					private IFptr fptr;

					private void checkError() throws DriverException {
						int rc = fptr.get_ResultCode();
						if (rc < 0) {
							String rd = fptr.get_ResultDescription(), bpd = null;
							if (rc == -6) {
								bpd = fptr.get_BadParamDescription();
							}
							if (bpd != null) {
								throw new DriverException(String.format("[%d] %s (%s)", rc, rd, bpd));
							} else {
								throw new DriverException(String.format("[%d] %s", rc, rd));
							}
						}
					}

					private void printText(String text, int alignment, int wrap) throws DriverException {
						if (fptr.put_Caption(text) < 0) {
							checkError();
						}
						if (fptr.put_TextWrap(wrap) < 0) {
							checkError();
						}
						if (fptr.put_Alignment(alignment) < 0) {
							checkError();
						}
						if (fptr.PrintString() < 0) {
							checkError();
						}
					}

					private void printText(String text) throws DriverException {
						printText(text, IFptr.ALIGNMENT_CENTER, IFptr.WRAP_LINE);
					}

					private void openCheck(int type) throws DriverException {
						if (fptr.put_Mode(IFptr.MODE_REGISTRATION) < 0) {
							checkError();
						}
						if (fptr.SetMode() < 0) {
							checkError();
						}
						if (fptr.put_CheckType(type) < 0) {
							checkError();
						}
						if (fptr.OpenCheck() < 0) {
							checkError();
						}
					}

					private void closeCheck(int typeClose) throws DriverException {
						if (fptr.put_TypeClose(typeClose) < 0) {
							checkError();
						}
						if (fptr.CloseCheck() < 0) {
							checkError();
						}
					}

					private void registration(String name, double price, double quantity) throws DriverException {
						if (fptr.put_Quantity(quantity) < 0) {
							checkError();
						}
						if (fptr.put_Price(price) < 0) {
							checkError();
						}
						if (fptr.put_TextWrap(IFptr.WRAP_WORD) < 0) {
							checkError();
						}
						if (fptr.put_Name(name) < 0) {
							checkError();
						}
						if (fptr.Registration() < 0) {
							checkError();
						}
					}

					private void registrationFZ54(String name, double price, double quantity,
												  double positionSum, int taxNumber) throws DriverException {
						if (fptr.put_TaxNumber(taxNumber) < 0) {
							checkError();
						}
						if (fptr.put_PositionSum(positionSum) < 0) {
							checkError();
						}
						if (fptr.put_Quantity(quantity) < 0) {
							checkError();
						}
						if (fptr.put_Price(price) < 0) {
							checkError();
						}
						if (fptr.put_TextWrap(IFptr.WRAP_WORD) < 0) {
							checkError();
						}
						if (fptr.put_Name(name) < 0) {
							checkError();
						}
						if (fptr.Registration() < 0) {
							checkError();
						}
					}

					private void payment(double sum, int type) throws DriverException {
						if (fptr.put_Summ(sum) < 0) {
							checkError();
						}
						if (fptr.put_TypeClose(type) < 0) {
							checkError();
						}
						if (fptr.Payment() < 0) {
							checkError();
						}
						publishProgress(String.format("Remainder: %.2f, Change: %.2f", fptr.get_Remainder(), fptr.get_Change()));
					}

					private void reportZ() throws DriverException {
						if (fptr.put_Mode(IFptr.MODE_REPORT_CLEAR) < 0) {
							checkError();
						}
						if (fptr.SetMode() < 0) {
							checkError();
						}
						if (fptr.put_ReportType(IFptr.REPORT_Z) < 0) {
							checkError();
						}
						if (fptr.Report() < 0) {
							checkError();
						}
					}

					private void printFooter() throws DriverException {
						if (fptr.put_Mode(IFptr.MODE_REPORT_NO_CLEAR) < 0) {
							checkError();
						}
						if (fptr.SetMode() < 0) {
							checkError();
						}
						if (fptr.PrintFooter() < 0) {
							checkError();
						}
					}

					private void printBarcode(int type, String barcode, double scale) throws DriverException {
						if (fptr.put_Alignment(IFptr.ALIGNMENT_CENTER) < 0) {
							checkError();
						}
						if (fptr.put_BarcodeType(type) < 0) {
							checkError();
						}
						if (fptr.put_Barcode(barcode) < 0) {
							checkError();
						}
						if (type == IFptr.BARCODE_TYPE_QRCODE) {
							if (fptr.put_Height(0) < 0) {
								checkError();
							}
						} else {
							if (fptr.put_Height(50) < 0) {
								checkError();
							}
						}
						if (fptr.put_BarcodePrintType(IFptr.BARCODE_PRINTTYPE_AUTO) < 0) {
							checkError();
						}
						if (fptr.put_PrintBarcodeText(false) < 0) {
							checkError();
						}
						if (fptr.put_BarcodeControlCode(true) < 0) {
							checkError();
						}
						if (fptr.put_Scale(scale) < 0) {
							checkError();
						}
						if (fptr.put_BarcodeCorrection(0) < 0) {
							checkError();
						}
						if (fptr.put_BarcodeColumns(3) < 0) {
							checkError();
						}
						if (fptr.put_BarcodeRows(1) < 0) {
							checkError();
						}
						if (fptr.put_BarcodeProportions(50) < 0) {
							checkError();
						}
						if (fptr.put_BarcodeUseProportions(true) < 0) {
							checkError();
						}
						if (fptr.put_BarcodePackingMode(IFptr.BARCODE_PDF417_PACKING_MODE_DEFAULT) < 0) {
							checkError();
						}
						if (fptr.put_BarcodePixelProportions(300) < 0) {
							checkError();
						}
						if (fptr.PrintBarcode() < 0) {
							checkError();
						}
					}

					private void discount(double sum, int type, int destination) throws DriverException {
						if (fptr.put_Summ(sum) < 0) {
							checkError();
						}
						if (fptr.put_DiscountType(type) < 0) {
							checkError();
						}
						if (fptr.put_Destination(destination) < 0) {
							checkError();
						}
						if (fptr.Discount() < 0) {
							checkError();
						}
					}

					private void charge(double sum, int type, int destination) throws DriverException {
						if (fptr.put_Summ(sum) < 0) {
							checkError();
						}
						if (fptr.put_DiscountType(type) < 0) {
							checkError();
						}
						if (fptr.put_Destination(destination) < 0) {
							checkError();
						}
						if (fptr.Charge() < 0) {
							checkError();
						}
					}

					@Override
					protected void onPreExecute() {
						buttonsLayout.setVisibility(View.GONE);
					}

					@Override
					protected void onPostExecute(Void result) {
						buttonsLayout.setVisibility(View.VISIBLE);
					}

					@Override
					protected Void doInBackground(Void... params) {
						Random random = new Random();
						fptr = new Fptr();
						try {
							fptr.create(getApplication());

							publishProgress("Загрузка настроек...");
							if (fptr.put_DeviceSettings(getSettings()) < 0) {
								checkError();
							}

							publishProgress("Установка соединения...");
							if (fptr.put_DeviceEnabled(true) < 0) {
								checkError();
							}
							publishProgress("OK");

							publishProgress("Проверка связи...");
							if (fptr.GetStatus() < 0) {
								checkError();
							}
							publishProgress("OK");

							// Отменяем чек, если уже открыт. Ошибки "Неверный режим" и "Чек уже закрыт"
							// не являются ошибками, если мы хотим просто отменить чек
							publishProgress("Отмена чека...");
							try {
								if (fptr.CancelCheck() < 0) {
									checkError();
								}
							} catch (DriverException e) {
								int rc = fptr.get_ResultCode();
								if (rc != -16 && rc != -3801) {
									throw e;
								}
							}
							publishProgress("OK");

							if (PRINT_FISCAL_CHECK) {
								publishProgress("Фискальный чек...");
								// Открываем чек продажи, попутно обработав превышение смены
								publishProgress("Открытие чека...");
								try {
									openCheck(IFptr.CHEQUE_TYPE_SELL);
								} catch (DriverException e) {
									// Проверка на превышение смены
									if (fptr.get_ResultCode() == -3822) {
										reportZ();
										openCheck(IFptr.CHEQUE_TYPE_SELL);
									} else {
										throw e;
									}
								}

								BigDecimal sum = new BigDecimal(0);
								for (int i = -2; i < 5; ++i) {
									if(USE_FZ54)
									{
										double price = Math.pow(10, i), quantity = 1;
										publishProgress(String.format("Регистрация %d", i + 3));
										registrationFZ54(String.format("Позиция %d", i + 3), price, quantity, price*quantity, IFptr.TAX_VAT_18);
										sum = sum.add(new BigDecimal(price).multiply(new BigDecimal(quantity)));
									}
									else {
										double price = Math.pow(10, i), quantity = 1;
										publishProgress(String.format("Регистрация %d", i + 3));
										registration(String.format("Позиция %d", i + 3), price, quantity);
										sum = sum.add(new BigDecimal(price).multiply(new BigDecimal(quantity)));
										// Скидка на позицию
										publishProgress("Скидка на позицию");
										if (i % 2 == 0) {
											discount(1, IFptr.DISCOUNT_SUMM, IFptr.DESTINATION_POSITION);
										} else {
											charge(1, IFptr.DISCOUNT_PERCENT, IFptr.DESTINATION_POSITION);
										}
									}
								}
								// Скидка на чек
								publishProgress("Скидка на чек");
								if (USE_FZ54) {
									// Можно сбрасывать в пределах копеек. При подаче 0 копейки отбрасываются полностью
									discount(0, IFptr.DISCOUNT_SUMM, IFptr.DESTINATION_CHECK);
								}
								else {
									discount(1, IFptr.DISCOUNT_PERCENT, IFptr.DESTINATION_CHECK);
								}

								// Оплачиваем
								publishProgress("Оплата...");
								payment(sum.divide(new BigDecimal(4)).doubleValue(), 1);
								payment(sum.divide(new BigDecimal(4)).doubleValue(), 2);
								payment(sum.divide(new BigDecimal(4)).doubleValue(), 3);
								payment(sum.doubleValue(), 0);
								// Закрываем чек
								publishProgress("Закрытие чека");
								closeCheck(0);
							}

							if (PRINT_NONFISCAL_CHECK) {
								publishProgress("Печать строк");
								publishProgress("Нефискальный чек...");
								printText("Я сразу смазал карту будня, плеснувши краску из стакана;\n"
									+ "Я показал на блюде студня косые скулы океана.\n"
									+ "На чешуе жестяной рыбы прочел я зовы новых губ.", IFptr.ALIGNMENT_LEFT, IFptr.WRAP_WORD);
								printText("А вы", IFptr.ALIGNMENT_LEFT, IFptr.WRAP_WORD);
								printText("ноктюрн сыграть", IFptr.ALIGNMENT_CENTER, IFptr.WRAP_WORD);
								printText("могли бы", IFptr.ALIGNMENT_RIGHT, IFptr.WRAP_WORD);
								printText("на флейте водосточных труб?", IFptr.ALIGNMENT_LEFT, IFptr.WRAP_WORD);
								publishProgress("OK");

								publishProgress("Печать ШК");
								printText("\nEAN8", IFptr.ALIGNMENT_CENTER, IFptr.WRAP_LINE);
								printBarcode(IFptr.BARCODE_TYPE_EAN8, "40182735", 100);
								printText("");
								printText("\nEAN13", IFptr.ALIGNMENT_CENTER, IFptr.WRAP_LINE);
								printBarcode(IFptr.BARCODE_TYPE_EAN13, "4007630000116", 200);
								printText("");
								printText("\nUPCA", IFptr.ALIGNMENT_CENTER, IFptr.WRAP_LINE);
								printBarcode(IFptr.BARCODE_TYPE_UPCA, "697929110035", 100);
								printText("");
								printText("\nCODE39", IFptr.ALIGNMENT_CENTER, IFptr.WRAP_LINE);
								printBarcode(IFptr.BARCODE_TYPE_CODE39, "ATOL.RU", 100);
								printText("");
								printText("\nPDF417", IFptr.ALIGNMENT_CENTER, IFptr.WRAP_LINE);
								printBarcode(IFptr.BARCODE_TYPE_PDF417, "1234567", 200);
								printText("");
								printText("\nQR", IFptr.ALIGNMENT_CENTER, IFptr.WRAP_LINE);
								printBarcode(IFptr.BARCODE_TYPE_QRCODE, "АТОЛ.РУ", 500);
								printText("");
								printText("\nITF-14", IFptr.ALIGNMENT_CENTER, IFptr.WRAP_LINE);
								printBarcode(IFptr.BARCODE_TYPE_ITF14, "00012345600012", 100);
								printText("");
								printText("\nInterleaved 2 of 5", IFptr.ALIGNMENT_CENTER, IFptr.WRAP_LINE);
								printBarcode(IFptr.BARCODE_TYPE_INTERLEAVED_2_OF_5, "04062300106659", 100);
								printText("");
								printFooter();
								publishProgress("OK");
							}
						} catch (Exception e) {
							publishProgress(e.toString());
						} finally {
							fptr.destroy();
						}
						return null;
					}

					@Override
					protected void onProgressUpdate(String... values) {
						if (values == null || values.length == 0) {
							return;
						}
						logAdd(values[0]);
					}

				};
				task.execute();
			}
		});

	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		if (requestCode == REQUEST_SHOW_SETTINGS) {
			if (data != null && data.getExtras() != null) {
				String settings = data.getExtras().getString(SettingsActivity.DEVICE_SETTINGS);
				setSettings(settings);
			}
		}
	}

	private String getSettings() {
		return preferences.getString(SettingsActivity.DEVICE_SETTINGS, getDefaultSettings());
	}

	private void setSettings(String settings) {
		SharedPreferences.Editor editor = preferences.edit();
		editor.putString(SettingsActivity.DEVICE_SETTINGS, settings);
		editor.apply();
	}

	private String getDefaultSettings() {
		IFptr fprint = new Fptr();
		fprint.create(this);
		String settings = fprint.get_DeviceSettings();
		fprint.destroy();
		return settings;
	}

	private void logAdd(String string) {
		String value = (String) log.getText();
		if (value.length() > 2096) {
			value = value.substring(0, 2096);
		}
		log.setText(string + "\n" + value);
	}

	private static class DriverException extends Exception {
		public DriverException(String msg) {
			super(msg);
		}
	}
}
